==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/sc.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Ligòngiu pùblicu",
    "Photos" : "Fotografias",
    "Your memories under your control" : "Is regordos tuos controllados",
    "Videos" : "Vìdeos",
    "Albums" : "Album",
    "People" : "Gente",
    "Folders" : "Cartellas",
    "Favorites" : "Preferidos",
    "Shared with you" : "Cumpartzidu cun tegus",
    "Tags" : "Etichetas",
    "Back" : "In segus",
    "Save" : "Sarva",
    "Shared by" : "Cumpartzidu dae",
    "Create a new album." : "Crea un'album nou.",
    "Create new album" : "Crea un'album nou.",
    "New album" : "Album nou",
    "_%n item_::_%n photos and videos_" : ["%n elementu","%n fotografias e vìdeos"],
    "No recommendations. Start typing." : "Peruna racumandatzione. Cumintza a iscrìere.",
    "Group" : "Grupu",
    "Copy the public link" : "Còpia su ligòngiu pùblicu",
    "Copy public link" : "Còpia ligòngiu pùblicu",
    "An error occurred" : "B'at àpidu un'errore",
    "Favorite" : "Preferidu",
    "Open the full size \"{name}\" image" : "Aberi s'immàgine \"{name}\" a mannària prena",
    "Back to {folder}" : "Torra a {folder}",
    "Go back" : "In segus",
    "Share this folder" : "Cumpartzi custa cartella",
    "Enable squared photos view" : "Ativa sa visualizatzione a fotos cuadradas",
    "Home" : "Pàgina printzipale",
    "View" : "Visualiza",
    "Unselect all" : "Deseletziona totu",
    "Remove from favorites" : "Boga·nche dae preferidos",
    "This folder does not exist" : "Custa cartella no esistit",
    "No photos in here" : "Peruna fotografia inoghe",
    "No tags yet" : "Ancora peruna eticheta",
    "Photos with tags will show up here" : "Is fotografias etichetadas ant a aparèssere inoghe",
    "Delete selection" : "Cantzella seletzione",
    "Tagged photos" : "Fotografias etichetadas",
    "Details" : "Detàllios",
    "Add" : "Agiunghe"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/sc.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Ligòngiu pùblicu",
    "Photos" : "Fotografias",
    "Your memories under your control" : "Is regordos tuos controllados",
    "Videos" : "Vìdeos",
    "Albums" : "Album",
    "People" : "Gente",
    "Folders" : "Cartellas",
    "Favorites" : "Preferidos",
    "Shared with you" : "Cumpartzidu cun tegus",
    "Tags" : "Etichetas",
    "Back" : "In segus",
    "Save" : "Sarva",
    "Shared by" : "Cumpartzidu dae",
    "Create a new album." : "Crea un'album nou.",
    "Create new album" : "Crea un'album nou.",
    "New album" : "Album nou",
    "_%n item_::_%n photos and videos_" : ["%n elementu","%n fotografias e vìdeos"],
    "No recommendations. Start typing." : "Peruna racumandatzione. Cumintza a iscrìere.",
    "Copy the public link" : "Còpia su ligòngiu pùblicu",
    "Copy public link" : "Còpia ligòngiu pùblicu",
    "An error occurred" : "B'at àpidu un'errore",
    "Favorite" : "Preferidu",
    "Open the full size \"{name}\" image" : "Aberi s'immàgine \"{name}\" a mannària prena",
    "Go back" : "In segus",
    "All folders" : "Totu is cartellas",
    "Home" : "Pàgina printzipale",
    "Unselect all" : "Deseletziona totu",
    "Remove from favorites" : "Boga·nche dae preferidos",
    "This folder does not exist" : "Custa cartella no esistit",
    "No photos in here" : "Peruna fotografia inoghe",
    "No tags yet" : "Ancora peruna eticheta",
    "Photos with tags will show up here" : "Is fotografias etichetadas ant a aparèssere inoghe",
    "Delete selection" : "Cantzella seletzione",
    "Tagged photos" : "Fotografias etichetadas",
    "Last week" : "Sa chida passada",
    "Details" : "Detàllios",
    "Cancel" : "Cancel",
    "Confirm" : "Cunfirma",
    "Group" : "Grupu",
    "Back to {folder}" : "Torra a {folder}",
    "Share this folder" : "Cumpartzi custa cartella",
    "Enable squared photos view" : "Ativa sa visualizatzione a fotos cuadradas",
    "View" : "Visualiza",
    "Add" : "Agiunghe"
},
"nplurals=2; plural=(n != 1);");
